summaryrefslogtreecommitdiff
path: root/examples/hello_dictd/libdz/dz.c
diff options
context:
space:
mode:
Diffstat (limited to 'examples/hello_dictd/libdz/dz.c')
-rw-r--r--examples/hello_dictd/libdz/dz.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/hello_dictd/libdz/dz.c b/examples/hello_dictd/libdz/dz.c
index 1fbe98e..81442b5 100644
--- a/examples/hello_dictd/libdz/dz.c
+++ b/examples/hello_dictd/libdz/dz.c
@@ -5,10 +5,10 @@ int fake3 (void)
return 3;
}
-/* fake must not be exported */
-int fake2 (void);
+/* fake22 must not be exported */
+int fake22 (void);
-int fake2 (void)
+int fake22 (void)
{
- return 2;
+ return 22;
}